//
// Simple Uart0 driver for 9s12DJ64 controller
//
// Juha Niinikoski 22.05.2007
//


#include <hidef.h>                        /* common defines and macros */
#include <mc9s12dj64.h>                   /* derivative information */
#pragma LINK_INFO DERIVATIVE "mc9s12dj64"

#include "J1850_conv.h"                   // board specific definitions



/* Simple OH2NLT SCI I/O routines */

void SCI0Init(void)                       /* Init SCI 0 */
  {
  SCI0BDL = (unsigned char)((16000000UL /* OSC freq */ / 2) / 9600 /* baud rate */ / 16 /*factor*/); 
  SCI0CR2 = 0x0C;
  }


void putch(unsigned char ch)              /* Print one character */
  {
 
  while (!(SCI0SR1 & 0x80));              /* wait for output buffer empty */
  SCI0DRL = ch;
  }


void putchhex(unsigned char c)            /* Print HEX character */
{
	unsigned char temp;

	temp=c;

	c=(c >> 4);
	if (c<10) c+=48; else c+=55;
	putch(c);

	c=temp;

	c=(c & 0x0F);
	if (c<10) c+=48; else c+=55;
	putch(c);
}



void putstr(const char *text)             /* Print string */
  {
  while (*text != '\0')
    {
    while (!(SCI0SR1 & 0x80));           /* wait for output buffer empty */
    SCI0DRL = *text++;
    }
  }


unsigned char kbhit(void)         /* check key hit, return character if hit */
  {
  unsigned char r;
  
  if ((SCI0SR1 & 0x20) == 0)            /* check hit */
     return 0;                          /* return with null if nothing */
  
  r = SCI0SR1;                          /* dummy read to clear flags */
  r = SCI0DRL;                          /* data read */
  
  return r;
  }
  

unsigned char getch(void)                /* get one character */
  {
  unsigned char r;
  
  while ((SCI0SR1 & 0x20) == 0);         /* wait for output buffer empty */  
  r = SCI0SR1;                           /* dummy read to clear flags */
  r = SCI0DRL;                           /* data read */
  
  return r;
  }

